@@ -4,6 +4,7 @@
 from time import sleep
 import os
 import re
+import sys
 
 try:
     import rapidjson as json
@@ -68,7 +69,8 @@ class Articut:
         self.userDefinedDictFILE = None
         self.openDataPlaceAccessBOOL=False
         self.chemicalBOOL=True
-        self.fileSizeLimit = 1024 * 1024 * 10    # 10 MB
+        self.fileSizeMb = 10    # 10 MB
+        self.fileSizeLimit = self.fileSizeMb * 1024 * 1024
 
         # Toolkit
         self.analyse = AnalyseManager()
@@ -118,15 +120,16 @@ class Articut:
 
         if userDefinedDictFILE:
             try:
-                if os.path.getsize(userDefinedDictFILE) <= self.fileSizeLimit:
-                    userDefinedFile = json.load(open(userDefinedDictFILE, "r", encoding="utf8"))
+                userDefinedFile = json.load(open(userDefinedDictFILE, "r", encoding="utf8"))
+                if sys.getsizeof(json.dumps(userDefinedFile)) <= self.fileSizeLimit:
                     if type(userDefinedFile) == dict:
                         payload["user_defined_dict_file"] = userDefinedFile
                     else:
                         print("User Defined File must be dict type.")
                         return {"status": False, "msg": "UserDefinedDICT Parsing ERROR. Please check your the format and encoding."}
                 else:
-                    print("Maximum file size limit is 10 MB.")
+                    print("Maximum file size limit is {} MB.".format(self.fileSizeMb))
+                    return {"status": False, "msg": "Maximum UserDefinedDICT file size exceeded! (UserDefinedDICT file shall be samller than {} MB.)".format(self.fileSizeMb)}
             except Exception as e:
                 print("User Defined File Loading Error.")
                 print(str(e))
@@ -379,7 +382,7 @@ if __name__ == "__main__":
     print("\n標記結果：")
     pprint(resultDICT["result_pos"])
 
-    #列出目前可使用的 Articut 版本選擇。通常版本號愈大，完成度愈高。
+    列出目前可使用的 Articut 版本選擇。通常版本號愈大，完成度愈高。
     versions = articut.versions()
     print("\n##Avaliable Versions:")
     pprint(versions)
